function y = utc2gps(year, month, day, hour, min, sec)

%UTC2GPS - converts UTC time to GPS time without leap second correction
%
%SYNOPSIS
% Y = utc2gps(YEAR, MONTH, DAY, HOUR, MIN, SEC)
% 
%INPUTS
%   YEAR - UTC year (4 digit)
%   MONTH - UTC month (1-2 digits)
%   DAY - UTC day (1-2 digits)
%   HOUR - UTC hour (1-2 digits)
%   MIN - UTC minute (1-2 digits)
%   SEC - UTC second (1-2 digits)
% 
%OUTPUT
%   Y - GPS time in seconds
%
%   N.B. No correction to GPS time for leap seconds.
%
%AUTHOR
%   Shantanu Desai (No longer part of the LV Collaboration)

%  $Id: utc2gps.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% Check for errors
if sec < 0 || sec > 60
   error('utc2gps : sec must be between 0 and 60.')
end

if min < 0 || min > 60
   error('utc2gps : min must be between 0 and 60.')
end

if hour < 0 || hour > 23
   error('utc2gps : hour must be between 0 and 23.')
end

if day < 1 || hour > 31
   error('utc2gps : day must be between 1 and 31.')
end

if month < 1 || month > 12
   error('utc2gps : month must be between 1 and 12.')
end

if year < 1980
   warning('utc2gps : year is before zero GPS.')
end

% calculate the date number for the midnight on the previous day
Nday = datenum(year, month, day, 0, 0, 0);

% The GPS clock started on Jan. 6, 1980. This corresponds to
N0 = datenum('6-Jan-1980');

% The number of days (Nday) passed since that time and the corresponding 
% number of seconds (Nsec) is
Nday = Nday - N0;
Nsec = 24 * 3600 * Nday;

% add hours, minutes, and seconds, passed since the previous midnight
y = Nsec + sec + 60 * min + 3600 * hour; 

return
